@@ -6,13 +6,15 @@
 #' @template param_times
 #' @template param_id
 #' @template param_measure_properties
+#' @template param_man
 #' @export
 MeasureSurvAUC = R6Class("MeasureSurvAUC",
   inherit = MeasureSurvIntegrated,
   public = list(
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(integrated = TRUE, times, id, properties) {
+    initialize = function(integrated = TRUE, times, id, properties = character(),
+                          man = NA_character_) {
       if (class(self)[[1]] == "MeasureSurvAUC") {
         stop("This is an abstract class that should not be constructed directly.")
       }
@@ -25,7 +27,8 @@ MeasureSurvAUC = R6Class("MeasureSurvAUC",
         minimize = FALSE,
         packages = "survAUC",
         predict_type = "lp",
-        properties = properties
+        properties = properties,
+        man = man
       )
     }
   ),
@@ -35,7 +38,7 @@ MeasureSurvAUC = R6Class("MeasureSurvAUC",
 
       args = list()
       if ("requires_train_set" %in% self$properties) {
-        args$Surv.rsp = task$truth(train_set)
+        args$Surv.rsp = task$truth(train_set) # nolint
       }
       if ("requires_learner" %in% self$properties) {
         args$lp = learner$model$linear.predictors
@@ -47,12 +50,12 @@ MeasureSurvAUC = R6Class("MeasureSurvAUC",
       }
 
       if ("Surv.rsp.new" %in% names(formals(FUN))) {
-        args$Surv.rsp.new = prediction$truth
+        args$Surv.rsp.new = prediction$truth # nolint
       }
 
-      auc = invoke(FUN, lpnew = prediction$lp, .args = args)
+      auc = mlr3misc::invoke(FUN, lpnew = prediction$lp, .args = args)
 
-      if (self$integrated & !grepl("TNR|TPR", self$id)) {
+      if (self$integrated && !grepl("tnr|tpr", self$id)) {
         return(auc$iauc)
       } else {
         return(auc)
